pm4py.algo.discovery.ocel.ocpn package
======================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.discovery.ocel.ocpn.variants

Submodules
----------

pm4py.algo.discovery.ocel.ocpn.algorithm module
-----------------------------------------------

.. automodule:: pm4py.algo.discovery.ocel.ocpn.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.ocel.ocpn
   :members:
   :undoc-members:
   :show-inheritance:
